About

Home Data Embeddings Chatbot Feedback

# About this app

# Your number is -1!

This is a SvelteKit app. You can make your own by typing the following into your command line and following the prompts:

    npm create svelte@latest

The page you're looking at is purely static HTML, with no client-side interactivity needed. Because of that, we don't need to load any JavaScript. Try viewing the page's source, or opening the devtools network panel and reloading.